@@ -10,9 +10,11 @@ from . import cmocean
 from . import cartocolors
 from . import colorbrewer
 from . import cubehelix
+from . import lightbartlein
 from . import matplotlib
 from . import mycarta
+from . import scientific
 from . import wesanderson
 from . import tableau
 
-version = __version__ = '3.1.0'
+version = __version__ = '3.3.0'
